import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.util.Scanner;

public class AccountApp {

    // we are using a MySQL database
    public static final String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;
    private Account account = new Account();

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "");
            // setup our DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            AccountService accountService = new AccountService();
            int input = userInput();
            while(input != 5) {
                Scanner scanner = new Scanner(System.in);

                switch (input) {
                    case 1:
                        System.out.print("Please enter the name:  ");
                        String name = scanner.nextLine();
                        System.out.print("Please enter the password:  ");
                        String password = scanner.nextLine();
                        accountService.createAccount(name, password, accountDao);
                        break;

                    case 2:
                        accountService.readAccount(accountDao);
                        break;


                    case 3:
                        System.out.print("Please enter the id of the account you want to update:  ");
                        int id = scanner.nextInt();
                        accountService.updateAccount(accountDao, id);
                        break;

                    case 4:
                        System.out.print("Please enter the id of the account you want to delete:  ");
                        int deletedID = scanner.nextInt();
                        accountService.deleteAccount(accountDao, deletedID);
                        break;

                    default:
                }
                input = userInput();
            }


            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    private int userInput() {
        Scanner scanner = new Scanner(System.in);
        System.out.println("Press 1 to create a User ");
        System.out.println("Press 2 to read the database");
        System.out.println("Press 3 to update the database");
        System.out.println("Press 4 to delete a User");
        System.out.println("Press 5 to exit");
        System.out.print("-  ");
        return scanner.nextInt();
    }

    /**
     *  Read and write some example data.
     */
    private void processData() throws Exception {
        // create an instance of Account
        String name = "Jim Coakley";
        account.setName(name);

        // persist the account object to the database
        accountDao.create(account);
        int id = account.getId();
        System.out.println(id);
        // assign a password
        account.setPassword("_secret");
        // update the database after changing the object
        accountDao.update(account);
        // delete the account
        // accountDao.deleteById(id);
    }

    /**
     *  Setup our DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws  Exception {
        accountDao = DaoManager.createDao(connectionSource, Account.class);
    }
}
